@@ -3,17 +3,17 @@
 
 // Version defines
 #define WT_SERIES 4
-#define WT_MAJOR  9
-#define WT_MINOR  1
+#define WT_MAJOR  10
+#define WT_MINOR  2
 
 /*! \brief A constant that encodes the library version of %Wt
  *
  * You may use this constant to check for the version of %Wt at build-time.
  */
 #define WT_VERSION (((WT_SERIES & 0xff) << 24) | ((WT_MAJOR & 0xff) << 16) | ((WT_MINOR & 0xff) << 8))
-#define WT_VERSION_STR "4.9.1"
-#define WT_CLASS       "Wt4_9_1"
-#define WT_INCLUDED_VERSION Wt_4_9_1
+#define WT_VERSION_STR "4.10.2"
+#define WT_CLASS       "Wt4_10_2"
+#define WT_INCLUDED_VERSION Wt_4_10_2
 
 #define RUNDIR "/var/run/wt"
 #define WT_CONFIG_XML "/etc/wt/wt_config.xml"
@@ -33,7 +33,7 @@
 #define WT_WITH_SSL
 /* #undef WT_HAS_SAML */
 
-#define WT_USE_OPENGL
+/* #undef WT_USE_OPENGL */
 /* #undef WT_DEBUG_ENABLED */
 #define WT_THREADED
 
